@@ -1,13 +1,15 @@
 #[cfg(feature = "eyra")]
 extern crate eyra;
 
+use std::process::ExitCode;
+
 use miette::IntoDiagnostic;
 
 #[cfg(target_env = "musl")]
 #[global_allocator]
 static GLOBAL: mimalloc::MiMalloc = mimalloc::MiMalloc;
 
-fn main() -> miette::Result<()> {
+fn main() -> miette::Result<ExitCode> {
 	#[cfg(feature = "pid1")]
 	pid1::Pid1Settings::new()
 		.enable_log(cfg!(feature = "pid1-withlog"))
